@@ -30,6 +30,7 @@ def main(raw_args=None):
     mainSubCommandParser.add_parser("play", aliases="p", help="Play.")
     mainSubCommandParser.add_parser("pause", aliases="p", help="Pause.")
     mainSubCommandParser.add_parser("stop", aliases="s", help="Stop.")
+    mainSubCommandParser.add_parser("fade_out", aliases=["fo"], help="Fades out the volume to under 5, within about 3 seconds, and returns prompt.")
     mainSubCommandParser.add_parser("playlists", aliases=["pls"], help="List sonos playlists.")
 
     volume_commandParser = mainSubCommandParser.add_parser("volume", aliases="v", help="Get/set the volume")
@@ -87,6 +88,8 @@ def main(raw_args=None):
     elif args.sub_command in ["stop_after", "sa"]:
         client.stop_after(args.n)
         print(client.get_current_status())
+    elif args.sub_command in ["fade_out", "fo"]:
+        client.fade_out()
     elif args.sub_command in ["line_in", "li"]:
         client.switch_to_line_in(list(client.all_zones)[args.n])
         client.play()
