@@ -43,3 +43,8 @@ def test_playlists():
 
     if pl:
         client.remove_sonos_playlist(pl)
+
+def test_fade_out():
+    currVol = client.volume
+    client.fade_out()
+    client.volume = currVol
\ No newline at end of file
